@@ -46,9 +46,6 @@ static bool env_var_checked_p;
 #define DWG_LOGLEVEL loglevel
 #include "logging.h"
 
-// used by free.c:
-int dwg_obj_is_control(const Dwg_Object *obj);
-
 /*------------------------------------------------------------------------------
  * Public functions
  */
@@ -205,7 +202,7 @@ dwg_read_file(const char *restrict filename, Dwg_Data *restrict dwg)
 }
 
 /* if write support is enabled */
-#ifdef USE_WRITE
+#if defined(USE_WRITE) && !defined(DISABLE_DXF)
 
 /** dxf_read_file
  * returns 0 on success.
@@ -650,7 +647,7 @@ dwg_resolve_handle(const Dwg_Data * dwg, const BITCODE_BL absref)
   uint32_t i = hash_get(dwg->object_map, (uint32_t)absref);
   LOG_HANDLE("object_map{%lX} => %u\n", (unsigned long)absref, i);
   if (i == HASH_NOT_FOUND ||
-      i >= dwg->num_objects) //the latter being an invalid handle (read from DWG)
+      (BITCODE_BL)i >= dwg->num_objects) //the latter being an invalid handle (read from DWG)
     {
       // ignore warning on invalid handles. These are warned earlier already
       if (absref && absref < dwg->num_objects)
@@ -668,7 +665,11 @@ int
 dwg_resolve_handleref(Dwg_Object_Ref *restrict ref, const Dwg_Object *restrict obj)
 {
   /*
-   * With TYPEDOBJHANDLE 2-5 the code indicates the type of ownership.
+   * With TYPEDOBJHANDLE 2-5 the code indicates the type of ownership:
+   *   2 Soft owner
+   *   3 Hard owner
+   *   4 Soft pointer
+   *   5 Hard pointer
    * With OFFSETOBJHANDLE >5 the handle is stored as an offset from some other handle.
    */
  switch (ref->handleref.code)
