@@ -42,7 +42,7 @@
 /* The logging level for the write (encode) path.  */
 static unsigned int loglevel;
 /* the current version per spec block */
-static int cur_ver = 0;
+static unsigned int cur_ver = 0;
 
 #ifdef USE_TRACING
 /* This flag means we have checked the environment variable
@@ -144,7 +144,7 @@ static bool env_var_checked_p;
   { bit_write_TIMEBLL(dat, (BITCODE_TIMEBLL)_obj->name); \
     LOG_TRACE(#name ": " FORMAT_BL "." FORMAT_BL "\n", _obj->name.days, _obj->name.ms); }
 
-#define FIELD_CMC(name, dxf) bit_write_CMC(dat, &_obj->name)
+#define FIELD_CMC(name,dxf1,dxf2) bit_write_CMC(dat, &_obj->name)
 
 #define FIELD_BE(name, dxf)\
   bit_write_BE(dat, FIELD_VALUE(name.x), FIELD_VALUE(name.y), FIELD_VALUE(name.z));
@@ -162,7 +162,7 @@ static bool env_var_checked_p;
 
 #define FIELD_2RD_VECTOR(name, size, dxf) \
   OVERFLOW_CHECK(name, _obj->size) \
-  for (vcount=0; vcount < (long)_obj->size; vcount++)\
+  for (vcount=0; vcount < (BITCODE_BL)_obj->size; vcount++)\
     {\
       FIELD_2RD(name[vcount], dxf);\
     }
@@ -170,24 +170,26 @@ static bool env_var_checked_p;
 #define FIELD_2DD_VECTOR(name, size, dxf)\
   OVERFLOW_CHECK(name, _obj->size) \
   FIELD_2RD(name[0], dxf); \
-  for (vcount = 1; vcount < (long)_obj->size; vcount++)\
+  for (vcount = 1; vcount < (BITCODE_BL)_obj->size; vcount++)\
     {\
       FIELD_2DD(name[vcount], FIELD_VALUE(name[vcount - 1].x), FIELD_VALUE(name[vcount - 1].y), dxf);\
     }
 
 #define FIELD_3DPOINT_VECTOR(name, size, dxf)\
   OVERFLOW_CHECK(name, _obj->size) \
-  for (vcount=0; vcount < (long)_obj->size; vcount++) \
+  for (vcount=0; vcount < (BITCODE_BL)_obj->size; vcount++) \
     {\
       FIELD_3DPOINT(name[vcount], dxf);\
     }
 
 #define REACTORS(code)\
-  OVERFLOW_CHECK(name, obj->tio.object->num_reactors) \
-  SINCE (R_13) { \
-    for (vcount=0; vcount < (long)obj->tio.object->num_reactors; vcount++) \
-    {\
-      VALUE_HANDLE(obj->tio.object->reactors[vcount], reactors, code, 330); \
+  if (obj->tio.object->reactors) { \
+    OVERFLOW_CHECK(name, obj->tio.object->num_reactors) \
+    SINCE (R_13) { \
+      for (vcount=0; vcount < (BITCODE_BL)obj->tio.object->num_reactors; vcount++) \
+      {\
+        VALUE_HANDLE(obj->tio.object->reactors[vcount], reactors, code, 330); \
+      }\
     }\
   }
     
@@ -228,20 +230,20 @@ static bool env_var_checked_p;
 //FIELD_VECTOR_N(name, type, size, dxf):
 // writes a 'size' elements vector of data of the type indicated by 'type'
 #define FIELD_VECTOR_N(name, type, size, dxf)\
-  if (size > 0)\
+  if (size > 0 && _obj->name)\
     {\
       OVERFLOW_CHECK(name, size) \
-      for (vcount=0; vcount < (long)size; vcount++)\
+      for (vcount=0; vcount < (BITCODE_BL)size; vcount++)\
         {\
           bit_write_##type(dat, _obj->name[vcount]);\
           LOG_TRACE(#name "[%ld]: " FORMAT_##type "\n", (long)vcount, _obj->name[vcount]) \
         }\
     }
 #define FIELD_VECTOR_T(name, size, dxf)\
-  if (_obj->size > 0)\
+  if (_obj->size > 0 && _obj->name)\
     {\
       OVERFLOW_CHECK(name, _obj->size) \
-      for (vcount=0; vcount < (long)_obj->size; vcount++)\
+      for (vcount=0; vcount < (BITCODE_BL)_obj->size; vcount++)\
         {\
           PRE (R_2007) { \
             bit_write_TV(dat, _obj->name[vcount]);\
@@ -306,14 +308,15 @@ static bool env_var_checked_p;
     }
 
 #define HANDLE_VECTOR_N(name, size, code, dxf)\
-  if (size>0) \
-    assert(_obj->name); \
-  OVERFLOW_CHECK(name, size) \
-  for (vcount=0; vcount < (long)size; vcount++)\
-    {\
-      assert(_obj->name[vcount]); \
-      FIELD_HANDLE_N(name[vcount], vcount, code, dxf);   \
-    }
+  if (size>0 && _obj->name) { \
+    OVERFLOW_CHECK(name, size) \
+    for (vcount=0; vcount < (BITCODE_BL)size; vcount++)\
+      {\
+        if (_obj->name[vcount]) { \
+          FIELD_HANDLE_N(name[vcount], vcount, code, dxf); \
+        } \
+      } \
+  }
 
 #define FIELD_NUM_INSERTS(num_inserts, type, dxf)   \
   FIELD_RL(num_inserts, dxf)
@@ -414,10 +417,10 @@ EXPORT long dwg_add_##token (Dwg_Data * dwg)     \
 #define DWG_ENTITY(token) \
 static int dwg_encode_##token (Bit_Chain *restrict dat, Dwg_Object *restrict obj) \
 { \
-  int error; \
-  long vcount, rcount1, rcount2, rcount3, rcount4; \
+  BITCODE_BL vcount, rcount1, rcount2, rcount3, rcount4; \
   Dwg_Object_Entity *_ent = obj->tio.entity; \
   Dwg_Entity_##token * _obj = _ent->tio.token; \
+  int error; \
   Bit_Chain* hdl_dat = dat; \
   Bit_Chain* str_dat = dat; \
   Dwg_Data* dwg = obj->parent; \
@@ -445,8 +448,8 @@ static int dwg_encode_##token (Bit_Chain *restrict dat, Dwg_Object *restrict obj
 #define DWG_OBJECT(token) \
 static int dwg_encode_##token (Bit_Chain *restrict dat, Dwg_Object *restrict obj) \
 { \
-  int error = 0; \
-  long vcount, rcount1, rcount2, rcount3, rcount4; \
+  BITCODE_BL vcount, rcount1, rcount2, rcount3, rcount4; \
+  int error; \
   Bit_Chain* hdl_dat = dat; \
   Bit_Chain* str_dat = dat; \
   Dwg_Data* dwg = obj->parent; \
@@ -482,7 +485,7 @@ static int dwg_encode_##token (Bit_Chain *restrict dat, Dwg_Object *restrict obj
   }
 
 #undef DEBUG_POS
-#define DEBUG_POS()\
+#define DEBUG_POS\
   if (DWG_LOGLEVEL >= DWG_LOGLEVEL_TRACE) { \
     LOG_TRACE("DEBUG_POS @%u.%u / 0x%x (%lu)\n", (unsigned int)dat->byte, dat->bit, \
               (unsigned int)dat->byte, bit_position(dat)); \
@@ -1123,8 +1126,8 @@ dwg_encode_variable_type(Dwg_Data* dwg, Bit_Chain* dat, Dwg_Object* obj)
            klass->number, klass->dxfname, klass->proxyflag,                    \
            klass->wasazombie ? " was proxy" : "")
 
-#undef WARN_UNHANDLED_CLASS
-#undef WARN_UNTESTED_CLASS
+  #undef WARN_UNHANDLED_CLASS
+  #undef WARN_UNSTABLE_CLASS
 
   return DWG_ERR_UNHANDLEDCLASS;
 }
@@ -1587,8 +1590,8 @@ dwg_encode_common_entity_handle_data(Bit_Chain* dat, Bit_Chain* hdl_dat,
   Dwg_Object_Entity *ent;
   //Dwg_Data *dwg = obj->parent;
   Dwg_Object_Entity *_obj;
-  int i, error = 0;
-  long unsigned int vcount;
+  BITCODE_BL vcount;
+  int error = 0;
   ent = obj->tio.entity;
   _obj = ent;
 
