@@ -99,7 +99,7 @@ static unsigned int cur_ver = 0;
     PAIR_S(type, #name)
 #define ENDGEOMETRY LASTENDHASH
 
-//#define VALUE(value,type,dxf) \
+//#define VALUE(value,type,dxf)
 //    fprintf(dat->fh, FORMAT_##type, value)
 //#define VALUE_RC(value,dxf) VALUE(value, RC, dxf)
 
@@ -139,7 +139,7 @@ static unsigned int cur_ver = 0;
 #define FIELD_TV(name,dxf)      FIELD_TEXT(name, _obj->name)
 #define FIELD_TU(name,dxf)      FIELD_TEXT_TU(name, (BITCODE_TU)_obj->name)
 #define FIELD_T(name,dxf)
-//  { if (dat->version >= R_2007) { FIELD_TU(name, dxf); }    \
+//  { if (dat->version >= R_2007) { FIELD_TU(name, dxf); }
 //    else                        { FIELD_TV(name, dxf); } }
 #define FIELD_BT(name,dxf)    FIELD(name, BT, dxf);
 #define FIELD_4BITS(name,dxf) FIELD(name,4BITS,dxf)
@@ -168,7 +168,7 @@ static unsigned int cur_ver = 0;
             px, py, pz)
 #define FIELD_3DPOINT(name)     VALUE_3DPOINT(_obj->name.x, _obj->name.y, _obj->name.z)
 #define LASTFIELD_3DPOINT(name) LASTVALUE_3DPOINT(_obj->name.x, _obj->name.y, _obj->name.z)
-#define FIELD_CMC(name,dxf)
+#define FIELD_CMC(name,dxf1,dxf2)
 #define FIELD_TIMEBLL(name,dxf)
 
 //FIELD_VECTOR_N(name, type, size):
@@ -176,7 +176,7 @@ static unsigned int cur_ver = 0;
 // it all in the vector called 'name'.
 #define FIELD_VECTOR_N(name, type, size, dxf)\
     ARRAY; \
-    for (vcount=0; vcount < (int)size; vcount++)\
+    for (vcount=0; vcount < (BITCODE_BL)size; vcount++)\
       {\
         PREFIX fprintf(dat->fh, "\"" #name "\": " FORMAT_##type ",\n", _obj->name[vcount]); \
       }\
@@ -185,11 +185,11 @@ static unsigned int cur_ver = 0;
 #define FIELD_VECTOR_T(name, size, dxf)\
     ARRAY; \
     PRE (R_2007) { \
-      for (vcount=0; vcount < (int)_obj->size; vcount++) { \
+      for (vcount=0; vcount < (BITCODE_BL)_obj->size; vcount++) { \
         PREFIX fprintf(dat->fh, "\"" #name "\": \"%s\",\n", _obj->name[vcount]); \
       }\
     } else { \
-      for (vcount=0; vcount < (int)_obj->size; vcount++)\
+      for (vcount=0; vcount < (BITCODE_BL)_obj->size; vcount++)\
         FIELD_TEXT_TU(name, _obj->name[vcount]); \
     } \
     if (_obj->size) NOCOMMA;\
@@ -199,7 +199,7 @@ static unsigned int cur_ver = 0;
 
 #define FIELD_2RD_VECTOR(name, size, dxf)\
   ARRAY;\
-  for (vcount=0; vcount < (int)_obj->size; vcount++)\
+  for (vcount=0; vcount < (BITCODE_BL)_obj->size; vcount++)\
     {\
       FIELD_2RD(name[vcount], dxf);\
     }\
@@ -209,7 +209,7 @@ static unsigned int cur_ver = 0;
 #define FIELD_2DD_VECTOR(name, size, dxf)\
   ARRAY;\
   FIELD_2RD(name[0], 0);\
-  for (vcount = 1; vcount < (int)_obj->size; vcount++)\
+  for (vcount = 1; vcount < (BITCODE_BL)_obj->size; vcount++)\
     {\
       FIELD_2DD(name[vcount], FIELD_VALUE(name[vcount - 1].x), FIELD_VALUE(name[vcount - 1].y), dxf);\
     }\
@@ -218,15 +218,15 @@ static unsigned int cur_ver = 0;
 
 #define FIELD_3DPOINT_VECTOR(name, size, dxf)\
   ARRAY;\
-  for (vcount=0; vcount < (int)_obj->size; vcount++)\
+  for (vcount=0; vcount < (BITCODE_BL)_obj->size; vcount++)\
     {\
       FIELD_3DPOINT(name[vcount], dxf);\
     }\
   if (_obj->size) NOCOMMA;\
   ENDARRAY;
 
-#define WARN_UNTESTED_CLASS \
-      LOG_WARN("Untested Class %s %d %s (0x%x%s) -@%ld", is_entity ? "entity" : "object",\
+#define WARN_UNSTABLE_CLASS \
+      LOG_WARN("Unstable Class %s %d %s (0x%x%s) -@%ld", is_entity ? "entity" : "object",\
                klass->number, dxfname, klass->proxyflag,\
                klass->wasazombie ? " was proxy" : "",\
                obj->address + obj->size)
@@ -304,7 +304,7 @@ dwg_geojson_variable_type(Dwg_Data *restrict dwg, Bit_Chain *restrict dat,
   if (!strcmp(dxfname, "GEODATA"))
     {
       Dwg_Object_GEODATA *_obj = obj->tio.object->tio.GEODATA;
-      WARN_UNTESTED_CLASS;
+      WARN_UNSTABLE_CLASS;
       FEATURE(AcDbObject:AcDbGeoData, obj);
       //which fields?
       ENDFEATURE;
@@ -313,7 +313,7 @@ dwg_geojson_variable_type(Dwg_Data *restrict dwg, Bit_Chain *restrict dat,
   if (!strcmp(dxfname, "GEOPOSITIONMARKER"))
     {
       Dwg_Entity_GEOPOSITIONMARKER *_obj = obj->tio.entity->tio.GEOPOSITIONMARKER;
-      WARN_UNTESTED_CLASS;
+      WARN_UNSTABLE_CLASS;
       // now even with text
       FEATURE(AcDbEntity:AcDbGeoPositionMarker, obj);
       GEOMETRY(Point);
@@ -518,7 +518,7 @@ dwg_geojson_object(Bit_Chain *restrict dat, Dwg_Object *restrict obj)
 static int
 geojson_entities_write (Bit_Chain *restrict dat, Dwg_Data *restrict dwg)
 {
-  unsigned int i;
+  BITCODE_BL i;
 
   SECTION(features);
   for (i=0; i < dwg->num_objects; i++)
